@@ -1,7 +1,7 @@
 var searchData=
 [
   ['tan_0',['tan',['../a00534.html#ac96b7a51e7ac1923b3b1d1e85fbff53b',1,'rtl::math']]],
-  ['terminate_1',['terminate',['../a00878.html#af7ffa642d68ae530bc76b12ca5852ca6',1,'osl::Thread']]],
+  ['terminate_1',['terminate',['../a00878.html#af7ffa642d68ae530bc76b12ca5852ca6',1,'osl::Thread::terminate()'],['../a00598.html#af7ffa642d68ae530bc76b12ca5852ca6',1,'salhelper::Thread::terminate()']]],
   ['thread_2',['Thread',['../a00598.html#a1b544964df8448966d54099c5ecf2918',1,'salhelper::Thread::Thread()'],['../a00878.html#a354d6ff717692c854543da069c493a6a',1,'osl::Thread::Thread()']]],
   ['threaddata_3',['ThreadData',['../a00882.html#a3fac11314cd8ba1fb612a8ccf844d5cc',1,'osl::ThreadData']]],
   ['threadfunc_4',['threadFunc',['../a00530.html#a919fa4231771ea453e5996b0e288807a',1,'osl']]],
@@ -17,7 +17,7 @@ var searchData=
   ['tofloat_14',['toFloat',['../a00666.html#abdaa863f070efbbba3217f153e86b597',1,'rtl::OString::toFloat()'],['../a00754.html#a3cd23f1fcfa3b3592f58521e6ef81858',1,'rtl::OUString::toFloat()']]],
   ['toint32_15',['toInt32',['../a00666.html#ad32f2cb5209536626f9c480eead0fdde',1,'rtl::OString::toInt32()'],['../a00754.html#a219d053853643733ed7e5968b419cea3',1,'rtl::OUString::toInt32()']]],
   ['toint64_16',['toInt64',['../a00666.html#ad0ab2ecd6a337e72e748f52bcdfd40b1',1,'rtl::OString::toInt64()'],['../a00754.html#a8ae42d2bae89ab790eea5086ef2f3e4b',1,'rtl::OUString::toInt64()']]],
-  ['topointer_17',['toPointer',['../a00710.html#a027f3c945cf002b657b042fccfd4d23f',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;']]],
+  ['topointer_17',['toPointer',['../a00706.html#a027f3c945cf002b657b042fccfd4d23f',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;']]],
   ['tostring_18',['toString',['../a00662.html#a965537f83678d992905897020d0e2269',1,'rtl::OStringBuffer::toString()'],['../a00750.html#a7c9dd7d083321e2dbb65902e4bf6d8ec',1,'rtl::OUStringBuffer::toString()']]],
   ['touint32_19',['toUInt32',['../a00666.html#af6d3f89160f5499192513fc13879ba62',1,'rtl::OString::toUInt32()'],['../a00754.html#a8c37a38e8fc27aa24e03f56744db65c1',1,'rtl::OUString::toUInt32()']]],
   ['touint64_20',['toUInt64',['../a00666.html#a360c1fd2ff6962155edaac9507b7793b',1,'rtl::OString::toUInt64()'],['../a00754.html#a556cf4161fb21ac199ee8642141c30bd',1,'rtl::OUString::toUInt64()']]],
